@@ -46,7 +46,6 @@ enum {
 	CONNECTION_LIST_COL_DEV_PIX,
 	CONNECTION_LIST_COL_DEVICE,
 	CONNECTION_LIST_COL_STAT_PIX,
-	CONNECTION_LIST_COL_STATUS,
 	CONNECTION_LIST_COL_DESCR,
 
 	CONNECTION_LIST_COL_DATA,
@@ -76,6 +75,7 @@ static void on_connection_modified (GtkWidget *w, XstConnection *cxn);
 static void on_wvlan_adhoc_toggled (GtkWidget *w, XstConnection *cxn);
 static void on_ppp_update_dns_toggled (GtkWidget *w, XstConnection *cxn);
 static gboolean on_ip_address_focus_out (GtkWidget *widget, GdkEventFocus *event, XstConnection *cxn);
+static void on_connection_list_clicked (GtkWidget *w, gpointer data);
 
 #define W(s) my_get_widget (cxn->xml, (s))
 
@@ -85,6 +85,10 @@ static gboolean on_ip_address_focus_out (GtkWidget *widget, GdkEventFocus *event
 #define SET_STR(yy_prefix,xx) xst_ui_entry_set_text (GTK_ENTRY (W (yy_prefix#xx)), cxn->xx)
 #define SET_BOOL(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (W (yy_prefix#xx)), cxn->xx)
 #define SET_BOOL_NOT(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (W (yy_prefix#xx)), !cxn->xx)
+#define SET_INT(yy_prefix,xx) gtk_range_set_value (GTK_RANGE (GTK_SCALE (W (yy_prefix#xx))), cxn->xx)
+#define GET_INT(yy_prefix,xx) cxn->xx = gtk_range_get_value (GTK_RANGE (GTK_SCALE (W (yy_prefix#xx))))
+#define SET_DIAL_OPTION_MENU(yy_prefix, xx) gtk_option_menu_set_history (GTK_OPTION_MENU (W (yy_prefix#xx)), ((cxn->xx != NULL) && (strcmp (cxn->xx, "ATDP") == 0))?1:0)
+#define GET_DIAL_OPTION_MENU(yy_prefix, xx) cxn->xx = (gtk_option_menu_get_history (GTK_OPTION_MENU (W (yy_prefix#xx))) == 0)? g_strdup ("ATDT"): g_strdup ("ATDP")
 
 typedef struct {
 	GtkWidget *list;
@@ -315,6 +319,21 @@ connection_xml_wvsection_get_boolean (xmlNode *node, gchar *section_name, gchar
 	return ret;
 }
 
+static gint
+connection_xml_wvsection_get_int (xmlNode *node, gchar *section_name, gchar *elem)
+{
+	gchar *str;
+	gint ret;
+
+	str = connection_xml_wvsection_get_str (node, section_name, elem);
+	if (str) {
+		ret = atoi (str);
+		g_free (str);
+	}
+
+	return ret;
+}
+
 static xmlNode *
 connection_xml_wvsection_add (xmlNode *node, gchar *section_name, gchar *type)
 {
@@ -341,11 +360,17 @@ connection_xml_wvsection_save_str_to_node (xmlNode *node, gchar *section_name, g
 
 static void
 connection_xml_wvsection_save_boolean_to_node (xmlNode *node, gchar *section_name, 
-									  gchar *node_name, gboolean bool)
+					       gchar *node_name, gboolean bool)
 {
 	connection_xml_wvsection_save_str_to_node (node, section_name, node_name, bool? "1": "0");
 }
 
+static void
+connection_xml_wvsection_save_int_to_node (xmlNode *node, gchar *section_name, gchar *node_name, gint value)
+{
+	connection_xml_wvsection_save_str_to_node (node, section_name, node_name, g_strdup_printf ("%i", value));
+}
+
 extern gchar *
 connection_wvsection_name_generate (gchar *dev, xmlNode *root)
 {
@@ -406,7 +431,7 @@ load_pixbuf (const gchar *file)
 	GdkPixbuf *pb, *pb2;
 	gchar     *path;
 
-	path = g_concat_dir_and_file (PIXMAPS_DIR, file);
+	path = g_strconcat (PIXMAPS_DIR, "/", file, NULL);
 	pb = gdk_pixbuf_new_from_file (path, NULL);
 	g_free (path);
 
@@ -446,14 +471,6 @@ connection_get_stat_pixbuf (XstConnection *cxn)
 	return cxn->enabled ? active : inactive;
 }
 
-static const gchar *
-connection_get_stat_string (XstConnection *cxn)
-{
-	g_return_val_if_fail (cxn != NULL, NULL);
-
-	return cxn->enabled ? _("Active") : _("Inactive");
-}
-
 static GtkTreeModel *
 connection_list_model_new (void)
 {
@@ -464,7 +481,6 @@ connection_list_model_new (void)
 				    G_TYPE_STRING,
 				    GDK_TYPE_PIXBUF,
 				    G_TYPE_STRING,
-				    G_TYPE_STRING,
 				    G_TYPE_POINTER);
 	return GTK_TREE_MODEL (store);
 }
@@ -497,15 +513,10 @@ connection_list_add_columns (GtkTreeView *treeview)
 
 	pixbuf_renderer = gtk_cell_renderer_pixbuf_new ();
 
-	gtk_tree_view_column_pack_start (col, pixbuf_renderer, FALSE);
-	gtk_tree_view_column_add_attribute (col, pixbuf_renderer, "pixbuf", CONNECTION_LIST_COL_STAT_PIX);
-
-	text_renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (col, text_renderer, TRUE);
-	gtk_tree_view_column_add_attribute (col, text_renderer, "text", CONNECTION_LIST_COL_STATUS);
-
-	gtk_tree_view_append_column (treeview, col);
-
+	g_object_set (G_OBJECT (pixbuf_renderer), "xalign", 0.5, NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(treeview), -1, _("Status"), 
+	      pixbuf_renderer,"pixbuf", CONNECTION_LIST_COL_STAT_PIX, NULL);
+	                                                                    
 	/* Description */
 	text_renderer = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (_("Description"),
@@ -534,6 +545,44 @@ connection_list_select_row (GtkTreeSelection *selection, gpointer data)
 		connection_actions_set_sensitive (FALSE);
 }
 
+static void
+on_connection_list_clicked (GtkWidget *w, gpointer data)
+{
+	GtkTreePath *path;
+	GtkTreeViewColumn *column;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GList *column_list;
+	gint ncol;
+	GdkPixbuf *stat_icon;
+	XstConnection *cxn;
+
+	cxn = connection_list_get_active ();
+	column_list = gtk_tree_view_get_columns (GTK_TREE_VIEW (w));
+	gtk_tree_view_get_cursor (GTK_TREE_VIEW (w), &path, &column);
+							  
+	ncol = g_list_index (column_list, column) + 1;
+
+	if (ncol == CONNECTION_LIST_COL_STAT_PIX)
+	{
+		model = gtk_tree_view_get_model (GTK_TREE_VIEW (w));
+		gtk_tree_model_get_iter (model, &iter, path);
+		
+		if (!cxn->enabled)
+		{
+			if (cxn->type != XST_CONNECTION_LO)
+				on_connection_activate_clicked (w, NULL);
+		}
+		else
+		{
+			if (cxn->type != XST_CONNECTION_LO)
+				on_connection_deactivate_clicked (w, NULL);
+		}
+	}
+	g_list_free (column_list);
+	gtk_tree_path_free (path);
+}
+
 static void
 list_get_active_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
@@ -581,7 +630,7 @@ connection_iter (XstConnection *cxn, GtkTreeIter *iter)
 }
 
 GtkWidget *
-connection_list_new (void)
+connection_list_new (XstTool *tool)
 {
 	GtkWidget        *treeview;
 	GtkTreeSelection *select;
@@ -589,9 +638,13 @@ connection_list_new (void)
 
 	model = connection_list_model_new ();
 
-	treeview = gtk_tree_view_new_with_model (model);
+	treeview = xst_dialog_get_widget (tool->main_dialog, "connection_list");
+	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), model);
 	g_object_unref (G_OBJECT (model));
 
+	g_signal_connect (G_OBJECT (treeview), "cursor-changed", 
+	      G_CALLBACK (on_connection_list_clicked), NULL);
+
 	connection_list_add_columns (GTK_TREE_VIEW (treeview));
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
@@ -626,7 +679,6 @@ connection_list_append (XstConnection *cxn)
 			    CONNECTION_LIST_COL_DEV_PIX,  connection_get_dev_pixbuf (cxn),
 			    CONNECTION_LIST_COL_DEVICE,   cxn->dev,
 			    CONNECTION_LIST_COL_STAT_PIX, connection_get_stat_pixbuf (cxn),
-			    CONNECTION_LIST_COL_STATUS,   connection_get_stat_string (cxn),
 			    CONNECTION_LIST_COL_DESCR,    cxn->name,
 			    CONNECTION_LIST_COL_DATA,     cxn,
 			    -1);
@@ -708,10 +760,9 @@ connection_find_by_dev (GtkWidget *list, gchar *dev)
 static gboolean
 connection_type_is_lan (XstConnectionType type)
 {
-	return (type == XST_CONNECTION_ETH ||
-		type == XST_CONNECTION_WVLAN ||
-		type == XST_CONNECTION_IRLAN);
-
+	return ((type == XST_CONNECTION_ETH) ||
+		(type == XST_CONNECTION_WVLAN) ||
+		(type == XST_CONNECTION_IRLAN));
 }
 
 static gboolean
@@ -720,10 +771,11 @@ default_gw_find_static_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *
 	XstConnection *cxn;
 
 	gtk_tree_model_get (model, iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
+
 	if (cxn->enabled && connection_type_is_lan (cxn->type) &&
 	    (cxn->ip_config == IP_MANUAL) &&
 	    (cxn->gateway && *cxn->gateway)) {
-		* (XstConnection *)data = *cxn;
+		* (XstConnection **)data = cxn;
 		return TRUE;
 	}
 
@@ -753,7 +805,7 @@ default_gw_find_ppp_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *ite
 
 	gtk_tree_model_get (model, iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
 	if (cxn->enabled && cxn->type == XST_CONNECTION_PPP && cxn->set_default_gw) {
-		* (XstConnection *)data = *cxn;
+		* (XstConnection **)data = cxn;
 		return TRUE;
 	}
 
@@ -785,7 +837,7 @@ default_gw_find_dynamic_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter
 	if (cxn->enabled &&
 	    (cxn->type == XST_CONNECTION_ETH || cxn->type == XST_CONNECTION_WVLAN) &&
 	    (cxn->ip_config != IP_MANUAL)) {
-		* (XstConnection *)data = *cxn;
+		* (XstConnection **)data = cxn;
 		return TRUE;
 	}
 
@@ -816,7 +868,7 @@ default_gw_find_plip_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *it
 	gtk_tree_model_get (model, iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
 	if (cxn->enabled && (cxn->type == XST_CONNECTION_PLIP) &&
 	    (cxn->remote_address && *cxn->remote_address)) {
-		* (XstConnection *)data = *cxn;
+		* (XstConnection **)data = cxn;
 		return TRUE;
 	}
 
@@ -843,16 +895,11 @@ extern void
 connection_init_gui (XstTool *tool)
 {
 	XstConnectionUI *ui;
-	GtkWidget *container;
 	XstConnectionType i;
 
 	ui = g_new0 (XstConnectionUI, 1);
 
-	container = xst_dialog_get_widget (tool->main_dialog, "connection_list_sw");
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (container),
-					     GTK_SHADOW_ETCHED_IN);
-	ui->list = connection_list_new ();
-	gtk_container_add (GTK_CONTAINER (container), ui->list);
+	ui->list = connection_list_new (tool);
 
 	ui->def_gw_omenu = xst_dialog_get_widget (tool->main_dialog, "connection_def_gw_omenu");
 
@@ -869,9 +916,9 @@ connection_default_gw_find_item (GtkWidget *omenu, gchar *dev)
 	GList *l;
 	gchar *value;
 
-	for (l = gtk_object_get_data (GTK_OBJECT (omenu), "list");
+	for (l = g_object_get_data (G_OBJECT (omenu), "list");
 	     l; l = l->next) {
-		value = gtk_object_get_data (GTK_OBJECT (l->data), "value");
+		value = g_object_get_data (G_OBJECT (l->data), "value");
 		if (!strcmp (dev, value))
 			return l->data;
 	}
@@ -882,7 +929,7 @@ connection_default_gw_find_item (GtkWidget *omenu, gchar *dev)
 static void
 connection_default_gw_activate (GtkMenuItem *item, gpointer data)
 {
-	gtk_object_set_data (GTK_OBJECT (tool), "gatewaydev", data);
+	g_object_set_data (G_OBJECT (tool), "gatewaydev", data);
 }
 
 void
@@ -907,16 +954,16 @@ connection_default_gw_add (XstConnection *cxn)
 	
 	cpy = g_strdup (dev);
 	item = gtk_menu_item_new_with_label (dev);
-	gtk_signal_connect (GTK_OBJECT (item), "activate",
-			    GTK_SIGNAL_FUNC (connection_default_gw_activate),
+	g_signal_connect (G_OBJECT (item), "activate",
+			    G_CALLBACK (connection_default_gw_activate),
 			    (gpointer) cpy);
-	gtk_object_set_data (GTK_OBJECT (item), "value", cpy);
+	g_object_set_data (G_OBJECT (item), "value", cpy);
 	gtk_widget_show (item);
-	gtk_menu_append (GTK_MENU (menu), item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	
-	l = gtk_object_get_data (GTK_OBJECT (omenu), "list");
+	l = g_object_get_data (G_OBJECT (omenu), "list");
 	l = g_list_append (l, item);
-	gtk_object_set_data (GTK_OBJECT (omenu), "list", l);
+	g_object_set_data (G_OBJECT (omenu), "list", l);
 }
 
 void
@@ -934,11 +981,11 @@ connection_default_gw_remove (gchar *dev)
 
 	g_return_if_fail ((item = connection_default_gw_find_item (omenu, dev)));
 	
-	l = gtk_object_get_data (GTK_OBJECT (omenu), "list");
+	l = g_object_get_data (G_OBJECT (omenu), "list");
 	l = g_list_remove (l, item);
-	gtk_object_set_data (GTK_OBJECT (omenu), "list", l);
+	g_object_set_data (G_OBJECT (omenu), "list", l);
 
-	cpy = gtk_object_get_data (GTK_OBJECT (item), "value");
+	cpy = g_object_get_data (G_OBJECT (item), "value");
 	g_free (cpy);
 	
 	gtk_widget_destroy (item);
@@ -956,8 +1003,8 @@ connection_default_gw_init (XstTool *tool, gchar *dev)
 	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
 
 	item = gtk_menu_get_active (GTK_MENU (menu));
-	gtk_signal_connect (GTK_OBJECT (item), "activate",
-			    GTK_SIGNAL_FUNC (connection_default_gw_activate),
+	g_signal_connect (G_OBJECT (item), "activate",
+			    G_CALLBACK (connection_default_gw_activate),
 			    (gpointer) NULL);
 	/* Strange bug caused the "Auto" item to be unsensitive the first time. */
 	gtk_menu_shell_select_item (GTK_MENU_SHELL (menu), item);
@@ -966,7 +1013,7 @@ connection_default_gw_init (XstTool *tool, gchar *dev)
 	if (item) {
 		GList *l;
 
-		l = gtk_object_get_data (GTK_OBJECT (omenu), "list");
+		l = g_object_get_data (G_OBJECT (omenu), "list");
 		
 		gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), g_list_index (l, item) + 1);
 		gtk_menu_shell_select_item (GTK_MENU_SHELL (menu), item);
@@ -980,7 +1027,7 @@ connection_default_gw_get_connection (XstTool *tool)
 	XstConnectionUI *ui;
 
 	ui = (XstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
-	dev = gtk_object_get_data (GTK_OBJECT (tool), "gatewaydev");
+	dev = g_object_get_data (G_OBJECT (tool), "gatewaydev");
 	g_return_val_if_fail (dev != NULL, NULL);
 
 	return connection_find_by_dev (ui->list, dev);
@@ -1042,14 +1089,14 @@ connection_default_gw_set_manual (XstTool *tool, XstConnection *cxn)
 {
 	gchar *gateway;
 
-	gateway = gtk_object_get_data (GTK_OBJECT (tool), "gateway");
+	gateway = g_object_get_data (G_OBJECT (tool), "gateway");
 	if (gateway)
 		g_free (gateway);
 	gateway = NULL;
 
 	if (!cxn) {
-		gtk_object_set_data (GTK_OBJECT (tool), "gateway", NULL);
-		gtk_object_set_data (GTK_OBJECT (tool), "gatewaydev", NULL);
+		g_object_set_data (G_OBJECT (tool), "gateway", NULL);
+		g_object_set_data (G_OBJECT (tool), "gatewaydev", NULL);
 		return;
 	}
 
@@ -1065,16 +1112,16 @@ connection_default_gw_set_manual (XstTool *tool, XstConnection *cxn)
 			gateway = g_strdup (cxn->remote_address);
 		break;
 	case XST_CONNECTION_PPP:
-		gtk_object_set_data (GTK_OBJECT (tool), "gatewaydev", NULL);
+		g_object_set_data (G_OBJECT (tool), "gatewaydev", NULL);
 		break;
 	case XST_CONNECTION_LO:
 	default:
-		gtk_object_set_data (GTK_OBJECT (tool), "gatewaydev", NULL);
+		g_object_set_data (G_OBJECT (tool), "gatewaydev", NULL);
 		g_warning ("connection_default_gw_set_manual: shouldn't be here.");
 		break;
 	}
 
-	gtk_object_set_data (GTK_OBJECT (tool), "gateway", gateway);
+	g_object_set_data (G_OBJECT (tool), "gateway", gateway);
 }
 
 void
@@ -1195,6 +1242,8 @@ connection_get_ppp_from_node (xmlNode *node, XstConnection *cxn)
 		cxn->login = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "login");
 		cxn->password = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "password");
 		cxn->stupid = connection_xml_wvsection_get_boolean (node->parent, cxn->wvsection, "stupid");
+		cxn->volume = connection_xml_wvsection_get_int (node->parent, cxn->wvsection, "volume");
+		cxn->dial_command = connection_xml_wvsection_get_str (node->parent, cxn->wvsection, "dial_command");
 	} else {
 		cxn->wvsection = connection_wvsection_name_generate (cxn->dev, node->parent);
 		connection_xml_save_str_to_node (cxn->node, "wvsection", cxn->wvsection);
@@ -1203,10 +1252,13 @@ connection_get_ppp_from_node (xmlNode *node, XstConnection *cxn)
 		cxn->login = xst_xml_get_child_content (node, "login");
 		cxn->password = xst_xml_get_child_content (node, "password");
 		cxn->stupid = FALSE;
+		cxn->volume = 3;
+		cxn->dial_command = g_strdup ("ATDT");
 	}
 
 	/* PPP advanced */
 	cxn->persist = connection_xml_get_boolean (node, "persist");
+	cxn->noauth = connection_xml_get_boolean (node, "noauth");
 	cxn->serial_port = xst_xml_get_child_content (node, "serial_port");
 	cxn->set_default_gw = connection_xml_get_boolean (node, "set_default_gw");
 	cxn->dns1 = xst_xml_get_child_content (node, "dns1");
@@ -1529,6 +1581,8 @@ empty_ppp (XstConnection *cxn)
 	GET_STR ("ppp_", login);
 	GET_STR ("ppp_", password);
 	GET_BOOL ("ppp_", persist);
+	GET_INT ("ppp_", volume);
+	GET_DIAL_OPTION_MENU ("ppp_", dial_command);
 }
 
 static void
@@ -1671,10 +1725,12 @@ connection_config_save (XstConnection *cxn)
 static void
 on_connection_ok_clicked (GtkWidget *w, XstConnection *cxn)
 {
+
 	if (cxn->modified) {
 		if (connection_config_save (cxn))
 			gtk_widget_destroy (cxn->window);
 		cxn->creating = FALSE;
+		xst_dialog_modify (tool->main_dialog);
 	} else
 		gtk_widget_destroy (cxn->window);
 }
@@ -1736,7 +1792,7 @@ on_ip_address_focus_out (GtkWidget *widget, GdkEventFocus *event, XstConnection
 {
 	connection_check_netmask_gui (cxn);
 
-        return TRUE;
+        return FALSE;
 }
 
 static void
@@ -1766,7 +1822,7 @@ ip_config_menu_cb (GtkWidget *w, gpointer data)
 	XstConnection *cxn;
 	IPConfigType ip;
 
-	cxn = gtk_object_get_user_data (GTK_OBJECT (w));
+	cxn = g_object_get_data (G_OBJECT (w), "user_data");
 
 	if (cxn->frozen)
 		return;
@@ -1803,11 +1859,11 @@ fill_ip (XstConnection *cxn)
 	menu = gtk_menu_new ();
 	for (i = 0; i < 3; i++) {
 		menuitem = gtk_menu_item_new_with_label (_(bootproto_labels[i]));
-		gtk_object_set_user_data (GTK_OBJECT (menuitem), cxn);
-		gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-				    GTK_SIGNAL_FUNC (ip_config_menu_cb),
-				    GINT_TO_POINTER (i));
-		gtk_menu_append (GTK_MENU (menu), menuitem);
+		g_object_set_data (G_OBJECT (menuitem), "user_data", cxn);
+		g_signal_connect (G_OBJECT (menuitem), "activate",
+				  G_CALLBACK (ip_config_menu_cb),
+				  GINT_TO_POINTER (i));
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	}
 	gtk_widget_show_all (menu);
 
@@ -1835,6 +1891,8 @@ fill_ppp (XstConnection *cxn)
 	SET_STR ("ppp_", login);
 	SET_STR ("ppp_", password);
 	SET_BOOL ("ppp_", persist);
+	SET_INT ("ppp_", volume);
+	SET_DIAL_OPTION_MENU ("ppp_", dial_command);
 }
 
 static void
@@ -1991,8 +2049,6 @@ connection_actions_set_sensitive (gboolean state)
 	gchar *names[] = {
 		"connection_delete",
 		"connection_configure",
-		"connection_activate",
-		"connection_deactivate",
 		NULL
 	};
 
@@ -2019,7 +2075,7 @@ connection_configure (XstConnection *cxn)
 
 	cxn->frozen = TRUE;
 
-	s = g_concat_dir_and_file (INTERFACES_DIR, "network.glade");
+	s = g_strconcat (INTERFACES_DIR, "/", "network.glade", NULL);
 	cxn->xml = glade_xml_new (s, "connection_config_dialog", NULL);
 
 	g_assert (cxn->xml);
@@ -2027,6 +2083,7 @@ connection_configure (XstConnection *cxn)
 
 	hookup_callbacks (cxn);
 
+	cxn->noauth = TRUE;
 	cxn->window = W("connection_config_dialog");
 	cxn->tmp_ip_config = cxn->ip_config;
 
@@ -2111,9 +2168,12 @@ connection_save_to_node (XstConnection *cxn, xmlNode *root)
 		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "login", cxn->login);
 		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "password", cxn->password);
 		connection_xml_wvsection_save_boolean_to_node (root, cxn->wvsection, "stupid", cxn->stupid);
-		
+		connection_xml_wvsection_save_int_to_node (root, cxn->wvsection, "volume", cxn->volume);
+		connection_xml_wvsection_save_str_to_node (root, cxn->wvsection, "dial_command", cxn->dial_command);
+
 		/* PPP advanced */
 		connection_xml_save_boolean_to_node (node, "persist", cxn->persist);
+		connection_xml_save_boolean_to_node (node, "noauth", cxn->noauth);
 		connection_xml_save_str_to_node (node, "serial_port", cxn->serial_port);
 		connection_xml_save_boolean_to_node (node, "set_default_gw", cxn->set_default_gw);
 		connection_xml_save_str_to_node (node, "dns1", cxn->dns1);
@@ -2158,8 +2218,7 @@ connection_list_has_dialer (XstTool *tool)
 	if (!need_dialer)
 		return TRUE;
 
-	has_dialer = (gboolean) gtk_object_get_data (GTK_OBJECT (tool),
-						     "dialinstalled");
+	has_dialer = (gboolean) g_object_get_data (G_OBJECT (tool), "dialinstalled");
 
 	return has_dialer;
 }
