@@ -30,20 +30,12 @@
 
 #define COLOR_NORMAL "black"
 
-enum {
-	TABLE_USER,
-	TABLE_GROUP,
-	TABLE_DEFAULT,
-	TABLE_NET_GROUP,
-	TABLE_NET_USER,
-};
-
 /* User and group lists creation function */
-GtkWidget*		create_gtk_tree_list		(GtkWidget*);
+void                    create_gtk_tree_list		(GtkWidget*);
 void			populate_gtk_tree_list		(GtkTreeView*, GList*);
 
 /* User and group tables manipulation functions */
-void			construct_tables		(void);
+void			create_tables			(void);
 void			update_tables_complexity	(XstDialogComplexity);
 void			populate_all_tables		(void);
 xmlNodePtr		get_selected_row_node		(gint);
