@@ -44,65 +44,56 @@
 #define MAX_TOKENS 8
 
 extern XstTool *tool;
-
-static int reply;
-
-GtkWidget *user_settings_all = NULL;
-GtkWidget *user_settings_members = NULL;
+extern GList *groups_list;
+xmlNodePtr user_profile;
 
 static void
-user_fill_groups_gtktree (GtkWidget *widget, xmlNodePtr node)
+create_groups_lists (xmlNodePtr node, GList **user_settings_all_list, GList **user_settings_members_list)
 {
-	GList *groups, *members, *items;
-	
-	members = user_get_groups (node);
-	
-	if (widget == user_settings_all) {
-		groups = get_list_from_node ("name", node);
-		items = my_g_list_remove_duplicates (groups, members);
-	} else {
-		items = members;
-	}
-
-	my_gtktree_list_append_items (GTK_TREE_VIEW (widget), items);
+	*user_settings_members_list = user_get_groups (node);
+	*user_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("name", NODE_GROUP), *user_settings_members_list);
 }
 
 static void
-create_groups_lists (void)
+create_groups_gtk_trees (void)
 {
+	GtkWidget *user_settings_all = xst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = xst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	GtkWidget *add_button, *remove_button;
+	GtkTreeSelection *selection;
+	GtkSizeGroup *sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 	
-	/* We create the widgets, connect signals and attach data if they haven't been created already */
-	if (user_settings_all == NULL) {
-		user_settings_all = create_gtktree_list (xst_dialog_get_widget (tool->main_dialog, "user_settings_all"));
-		gtk_object_set_data (GTK_OBJECT (user_settings_all), "button", "user_settings_add");
-		gtk_signal_connect (GTK_OBJECT (user_settings_all),
-		                    "cursor_changed",
-		                    G_CALLBACK (on_list_select_row),
-		                    NULL);
+	/* connect signals and attach data if they haven't been created already */
+	if (g_object_get_data (G_OBJECT (user_settings_all), "button") == NULL) {
+		create_gtk_tree_list (user_settings_all);
+		g_object_set_data (G_OBJECT (user_settings_all), "button", "user_settings_add");
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_settings_all));
+		g_signal_connect (G_OBJECT (selection),
+		                  "changed",
+		                  G_CALLBACK (on_list_select_row),
+		                  NULL);
+
+		create_gtk_tree_list (user_settings_members);
+		g_object_set_data (G_OBJECT (user_settings_members), "button", "user_settings_remove");
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_settings_members));
+		g_signal_connect (G_OBJECT (selection),
+		                  "changed",
+		                  G_CALLBACK (on_list_select_row),
+		                  NULL);
 
-		user_settings_members = create_gtktree_list (xst_dialog_get_widget (tool->main_dialog, "user_settings_members"));
-		gtk_object_set_data (GTK_OBJECT (user_settings_members), "button", "user_settings_remove");
-		gtk_signal_connect (GTK_OBJECT (user_settings_members),
-		                    "cursor_changed",
-		                    G_CALLBACK (on_list_select_row),
-		                    NULL);
-		
 		/* We also need to attach some data to the 'add' and 'remove' buttons */
 		add_button = xst_dialog_get_widget (tool->main_dialog, "user_settings_add");
-		gtk_object_set_data (GTK_OBJECT (add_button), "in", user_settings_all);
-		gtk_object_set_data (GTK_OBJECT (add_button), "out", user_settings_members);
+		g_object_set_data (G_OBJECT (add_button), "in", user_settings_all);
+		g_object_set_data (G_OBJECT (add_button), "out", user_settings_members);
 		
 		remove_button = xst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
-		gtk_object_set_data (GTK_OBJECT (remove_button), "in", user_settings_members);
-		gtk_object_set_data (GTK_OBJECT (remove_button), "out", user_settings_all);
-	}
-}
+		g_object_set_data (G_OBJECT (remove_button), "in", user_settings_members);
+		g_object_set_data (G_OBJECT (remove_button), "out", user_settings_all);
 
-static void
-reply_cb (gint val, gpointer data)
-{
-        reply = val;
+		/* Add the scrolled windows that contain the trees in the same GtkSizeGroup */
+		gtk_size_group_add_widget (sizegroup, xst_dialog_get_widget (tool->main_dialog, "group_settings_all_container"));
+		gtk_size_group_add_widget (sizegroup, xst_dialog_get_widget (tool->main_dialog, "group_settings_members_container"));
+	}
 }
 
 static gboolean
@@ -110,7 +101,8 @@ check_user_delete (xmlNodePtr node)
 {
 	gchar *login, *buf;
 	GtkWindow *parent;
-	GnomeDialog *dialog;
+	GtkWidget *dialog;
+	gint reply;
 
 	g_return_val_if_fail (node != NULL, FALSE);
 
@@ -126,187 +118,115 @@ check_user_delete (xmlNodePtr node)
 	if (strcmp (login, "root") == 0)
 	{
 		buf = g_strdup (_("The root user must not be deleted."));
-		dialog = GNOME_DIALOG (gnome_error_dialog_parented (buf, parent));
-		gnome_dialog_run (dialog);
+		show_error_message ("user_settings_dialog", buf);
 		g_free (login);
 		g_free (buf);
 		return FALSE;
 	}
 
 	buf = g_strdup_printf (_("Are you sure you want to delete user %s?"), login);
-	dialog = GNOME_DIALOG (gnome_question_dialog_parented (buf, reply_cb, NULL, parent));
-	gnome_dialog_run (dialog);
+	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, buf);
+	reply = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 	g_free (buf);
 	g_free (login);
 	
-	if (reply)
+	if (reply == GTK_RESPONSE_NO)
 		return FALSE;
         else
 		return TRUE;
 }
 
-void
+gboolean
 delete_user (xmlNodePtr node)
 {
 	if (check_user_delete (node))
 	{
-		delete_selected_row (TABLE_USER);
 		del_user_groups (node);
 		xst_xml_element_destroy (node);
-		xst_dialog_modify (tool->main_dialog);
-		users_table_update_content ();
-		actions_set_sensitive (TABLE_USER, FALSE);
-	} 
-}
-
-static void
-shells_combo_setup ()
-{
-	xmlNodePtr root, node;
-	GtkWidget *combo;
-	GList *shells = NULL;
-	gchar *shell;
-
-	root = xst_xml_doc_get_root (tool->config);
-	root = xst_xml_element_find_first (root, "shelldb");
-	combo = xst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
-
-	if (!root)
-		return;
-	
-	for (node = xst_xml_element_find_first (root, "shell"); node != NULL; node = xst_xml_element_find_next (node, "shell"))
-	{
-		shell = xst_xml_element_get_content (node);
-		shells = g_list_append (shells, shell);
+		return TRUE;
 	}
 
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), shells);
-	g_list_free (shells);
+	return FALSE;
 }
 
-static void
-groups_combo_setup (gchar *entry)
+void
+user_set_profile (xmlNodePtr profile)
 {
-	GList *groups;
-	GtkWidget *combo = xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo");
-	gboolean found = FALSE;
+	gint counter = 0;
+	GList *element;
+	gchar *value;
+	gchar *buf;
 	ug_data *ud;
-
-	ud = gtk_object_get_data (GTK_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog")), "data");
-
-	groups = get_list_from_node ("name", ud->node);
+	GtkWidget *widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	
-	g_return_if_fail (groups != NULL);
+	ud = g_object_get_data (G_OBJECT (widget), "data");
 	
-	if (entry) {
-		GList *list = groups;
-		while (list && !found) {
-			if (strcmp (list->data, entry) == 0) {
-				found = TRUE;
-				break;
-			}
-			list = list->next;
-		}
-		
-		if (!found) {
-			groups = g_list_prepend (groups, entry);
-		}
+	gtk_entry_set_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_home")),
+			    xst_xml_get_child_content (profile, "home_prefix"));
+	gtk_entry_set_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")),
+			    xst_xml_get_child_content (profile, "shell"));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_max")),
+				   g_strtod (xst_xml_get_child_content (profile, "pwd_maxdays"), NULL));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_min")),
+				   g_strtod (xst_xml_get_child_content (profile, "pwd_mindays"), NULL));
+	gtk_spin_button_set_value ( GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_days")),
+				   g_strtod (xst_xml_get_child_content (profile, "pwd_warndays"), NULL));
+
+	value = xst_xml_get_child_content (profile, "group");
+	element = g_list_first (groups_list);
+
+	while ((element != NULL) && (strcmp (element->data, value) != 0))
+	{
+		element = element->next;
+		counter++;
 	}
-	
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), groups);
-	gtk_combo_set_value_in_list (GTK_COMBO (combo), TRUE, FALSE);
-	
-	g_list_free (groups);
-}
+	gtk_option_menu_set_history (GTK_OPTION_MENU (xst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
 
-void
-user_set_profile (const gchar *profile)
-{
-	GtkWidget *widget;
-	xmlNodePtr node, root;
-	gchar *buf;
-	
-	g_return_if_fail (profile != NULL);
-	
-	root = xst_xml_doc_get_root (tool->config);
-	root = xst_xml_element_find_first (root, "profiledb");
-	
-	for (node = xst_xml_element_find_first (root, "profile"); node != NULL; xst_xml_element_find_next (node, "profile")) {
-		if (strcmp (profile, xst_xml_get_child_content (node, "name")) == 0)
-			break;
-	}
-	
-	xst_ui_entry_set_text (xst_dialog_get_widget (tool->main_dialog, "user_settings_home"), xst_xml_get_child_content (node, "home_prefix"));
-	xst_ui_entry_set_text (xst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry"), xst_xml_get_child_content (node, "shell"));
-	
-	buf = xst_xml_get_child_content (node, "group");
-	groups_combo_setup (buf);
-	xst_ui_entry_set_text (xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo_entry"), buf);
-
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_max")), g_strtod (xst_xml_get_child_content (node, "pwd_maxdays"), NULL));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_min")), g_strtod (xst_xml_get_child_content (node, "pwd_mindays"), NULL));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_days")), g_strtod (xst_xml_get_child_content (node, "pwd_warndays"), NULL));
-}
-
-static void
-profiles_option_menu_setup (void)
-{
-	GtkWidget *menu_item;
-	GtkWidget *menu = xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu");
-	GList *profiles = get_profile_list ();
-	GList *list = profiles;
-	gint index, i=0;
-	
-	while (list) {
-		if (strcmp (list->data, "Default") == 0)
-			index = i;
-		menu_item = xst_ui_option_menu_add_string (GTK_OPTION_MENU (menu), list->data);
-		gtk_signal_connect (GTK_OBJECT (menu_item), "activate", GTK_SIGNAL_FUNC (on_user_settings_profile_changed), list->data);
-		list = list->next;
-		i++;
-	}
-	
-	/* we set the option menu to the 'Default' option */
-	gtk_option_menu_set_history (GTK_OPTION_MENU (menu), index);
-	user_set_profile ("Default");
-
-	g_list_free (profiles);
-}
-
-void
-user_new_prepare (ug_data *ud)
-{
-	GtkWidget *widget, *button;
-	gchar *buf;
-
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
-	gtk_window_set_title (GTK_WINDOW (widget), _("User Account Editor"));
-
-	/* Attach the data to the dialog */
-	gtk_object_set_data (GTK_OBJECT (widget), "data", ud);
-	
-	/* Profiles are disabled at the moment, showing advanced settings instead */
-	gtk_widget_show (xst_dialog_get_widget (tool->main_dialog, "user_settings_advanced"));
-	gtk_widget_hide (xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_box"));
-
-	/* Creates and fills GtkTrees */
-	create_groups_lists ();
-	user_fill_groups_gtktree (user_settings_all, ud->node);
-	
-	/* Fills profiles option menu */
-	profiles_option_menu_setup ();
-	
 	/* Gets a new uid */
-	buf = (gchar *) find_new_id (ud->node);
+	buf = (gchar *) find_new_id (ud->node, profile);
 	if (buf) {
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_settings_uid")), 
 		                           g_strtod (buf, NULL));
 		g_free (buf);
 	}
+
+	user_profile = profile;
+}
+
+void
+user_new_prepare (ug_data *ud)
+{
+	GtkWidget *button;
+	gchar *buf;
+	GList *user_settings_all_list = NULL;
+	GList *user_settings_members_list = NULL;
+	GtkWidget *widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+	GtkWidget *user_settings_all = xst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = xst_dialog_get_widget (tool->main_dialog, "user_settings_members");
+
+	gtk_window_set_title (GTK_WINDOW (widget), _("User Account Editor"));
+	g_object_set_data (G_OBJECT (widget), "data", ud);
+
+	gtk_widget_show (xst_dialog_get_widget (tool->main_dialog, "user_settings_profiles"));
 	
+	/* Creates and fills GtkTrees */
+	create_groups_gtk_trees ();
+	create_groups_lists (ud->node, &user_settings_all_list, &user_settings_members_list);
+	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_all), user_settings_all_list);
+	
+	/* Attach the GLists to the GtkTreeViews */
+	g_object_set_data (G_OBJECT (user_settings_all), "list", user_settings_all_list);
+	g_object_set_data (G_OBJECT (user_settings_members), "list", user_settings_members_list);
+	
+	/* Fill menus */
+	option_menu_add_profiles (xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu"));
+	option_menu_add_groups (xst_dialog_get_widget (tool->main_dialog, "user_settings_group"), TRUE);
+	combo_add_shells (xst_dialog_get_widget (tool->main_dialog, "user_settings_shell"));
+	
+#ifdef HAVE_LIBCRACK
 	/* If we have libcrack, password quality check is enabled */
 	button = xst_dialog_get_widget (tool->main_dialog, "user_passwd_quality");
-#ifdef HAVE_LIBCRACK
 	gtk_widget_show (button);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 #endif
@@ -317,10 +237,13 @@ user_new_prepare (ug_data *ud)
 void
 user_settings_dialog_close (void)
 {
+	GtkWidget *user_settings_all = xst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = xst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	GtkWidget *widget;
 	GtkTreeModel *model;
 	ug_data *ud;
 	gint i;
+	GList *list;
 	char *text_boxes[] = { 
 		"user_settings_name",
 		"user_settings_comment",
@@ -358,14 +281,26 @@ user_settings_dialog_close (void)
 	
 	/* Set the first notebook page as default for the next time the dialog is opened */
 	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
-	gtk_notebook_set_page (GTK_NOTEBOOK (widget), 0);
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 0);
 	
+	/* Clear the GLists attached to the GtkTreeViews */
+	list = g_object_get_data (G_OBJECT (user_settings_all), "list");
+	g_list_free (list);
+	g_object_steal_data (G_OBJECT (user_settings_all), "list");
+	
+	list = g_object_get_data (G_OBJECT (user_settings_members), "list");
+	g_list_free (list);
+	g_object_steal_data (G_OBJECT (user_settings_members), "list");
+
 	/* Clear user data attached to the widget */
 	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
-	ud = gtk_object_get_data (GTK_OBJECT (widget), "data");
+	ud = g_object_get_data (G_OBJECT (widget), "data");
 	g_free (ud);
-	gtk_object_remove_data (GTK_OBJECT (widget), "data");
+	g_object_steal_data (G_OBJECT (widget), "data");
 	gtk_widget_hide (widget);
+
+	/* Clear groups option menu */
+	gtk_option_menu_remove_menu (GTK_OPTION_MENU (xst_dialog_get_widget (tool->main_dialog, "user_settings_group")));
 }
 
 static gboolean
@@ -585,7 +520,7 @@ group_check (xmlNodePtr node, const gchar *groupname)
 	
 	gid = group_xml_get_gid (groupdb, (gchar *) groupname);
 	if (!gid) {
-		gid = find_new_id (groupdb);
+		gid = find_new_id (groupdb, user_profile);
 		group = group_add_blank_xml (groupdb);
 		group_update_xml (group, (gchar *) groupname, gid, NULL);
 	}
@@ -596,8 +531,10 @@ group_check (xmlNodePtr node, const gchar *groupname)
 gboolean
 user_update (ug_data *ud)
 {
+	GtkWidget *user_settings_members = xst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	UserAccountData *data;
 	gboolean change_password = FALSE;
+	GList *list;
 	
 	data = g_new (UserAccountData, 1);
 	
@@ -645,8 +582,8 @@ user_update (ug_data *ud)
 		if (!ud->is_new) {
 			/* If it is a modified user, we have to check that the entries are unchanged */
 			gboolean d1, d2;
-			d1 = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")), "changed"));
-			d2 = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")), "changed"));
+			d1 = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")), "changed"));
+			d2 = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")), "changed"));
 			if (d1 || d2) {
 				data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")));
 				data->password2 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")));
@@ -665,11 +602,11 @@ user_update (ug_data *ud)
 		}
 	} else {
 		/* Automatic password generation enabled */
-		data->password1 = (gchar *) gtk_label_get_text (GTK_LABEL (xst_dialog_get_widget (tool->main_dialog, "user_passwd_random_label")));
+		data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_random_entry")));
 	}
 
 	/* get user main group GID*/
-	data->group = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo_entry")));
+	data->group = g_list_nth_data (groups_list, gtk_option_menu_get_history (GTK_OPTION_MENU (xst_dialog_get_widget (tool->main_dialog, "user_settings_group"))));
 	if (strcmp (data->group, "$user") == 0)
 		data->group = data->login;
 	
@@ -677,9 +614,10 @@ user_update (ug_data *ud)
 	if (!data->gid) {
 		return FALSE;
 	}
-	
-	data->extra_groups = extract_members_list (GTK_TREE_VIEW (user_settings_members));
-	
+
+	g_list_free (data->extra_groups);
+	data->extra_groups = g_list_copy (g_object_get_data (G_OBJECT (user_settings_members), "list"));
+
 	data->pwd_maxdays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_max"))));
 	data->pwd_mindays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_min"))));
 	data->pwd_warndays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_days"))));
@@ -692,11 +630,12 @@ user_update (ug_data *ud)
 		user_update_xml (node, data, TRUE);
 	} else {
 		/* Entered data ok, not new: just update */
+		
+		del_user_groups (ud->node);
 		user_update_xml (ud->node, data, change_password);
 	}
 	
 	tables_update_content ();
-	
 	return TRUE;
 }
 
@@ -710,8 +649,8 @@ user_settings_dialog_prepare_password (void){
 	gtk_entry_set_text (GTK_ENTRY (pwd1), "********");
 	gtk_entry_set_text (GTK_ENTRY (pwd2), "********");
 	
-	gtk_object_set_data (GTK_OBJECT (pwd1), "changed", GINT_TO_POINTER (FALSE));
-	gtk_object_set_data (GTK_OBJECT (pwd2), "changed", GINT_TO_POINTER (FALSE));
+	g_object_set_data (G_OBJECT (pwd1), "changed", GINT_TO_POINTER (FALSE));
+	g_object_set_data (G_OBJECT (pwd2), "changed", GINT_TO_POINTER (FALSE));
 }
 
 static void
@@ -741,18 +680,24 @@ user_settings_dialog_prepare_comments (gchar *comments)
 static void
 user_settings_dialog_prepare (ug_data *ud)
 {
+	GtkWidget *user_settings_all = xst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = xst_dialog_get_widget (tool->main_dialog, "user_settings_members");
+	GtkWidget *option_menu = xst_dialog_get_widget (tool->main_dialog, "user_settings_group");
+	GtkWidget *combo = xst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
 	GtkWidget *w0;
 	gchar *txt, *name;
+	GList *user_settings_all_list = NULL;
+	GList *user_settings_members_list = NULL;
+	gint counter = 0;
+	GList *element;
 	
 	g_return_if_fail (ud != NULL);
 
-	/* Hides profiles combo, shows advanced settings */
-	gtk_widget_show (xst_dialog_get_widget (tool->main_dialog, "user_settings_advanced"));
-	gtk_widget_hide (xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_box"));
+	gtk_widget_hide (xst_dialog_get_widget (tool->main_dialog, "user_settings_profiles"));
 	
 	/* Attach the data to the dialog */
 	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
-	gtk_object_set_data (GTK_OBJECT (w0), "data", ud);
+	g_object_set_data (G_OBJECT (w0), "data", ud);
 
 	/* Set user login */
 	name = xst_xml_get_child_content (ud->node, "login");
@@ -775,23 +720,37 @@ user_settings_dialog_prepare (ug_data *ud)
 	g_free (txt);
 	
 	/* Set shells combo */
-	shells_combo_setup ();
+	combo_add_shells (combo);
 	txt = xst_xml_get_child_content (ud->node, "shell");
 	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry");
 	xst_ui_entry_set_text (w0, txt);
 	g_free (txt);
 	
-	/* set main group combo */
-	groups_combo_setup (NULL);
+	/* set main group option menu */
+	option_menu_add_groups (option_menu, FALSE);
 	txt = get_group_name (xst_xml_get_child_content (ud->node, "gid"));
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo_entry");
-	xst_ui_entry_set_text (w0, txt);
-	g_free (txt);
+
+	if (txt != NULL) {
+		element = g_list_first (groups_list);
+
+		while ((element != NULL) && (strcmp (element->data, txt) != 0))
+		{
+			element = element->next;
+			counter++;
+		}
+		gtk_option_menu_set_history (GTK_OPTION_MENU (xst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
+		g_free (txt);
+	}
 	
 	/* Fill groups lists */
-	create_groups_lists ();
-	user_fill_groups_gtktree (user_settings_all, ud->node);
-	user_fill_groups_gtktree (user_settings_members, ud->node);
+	create_groups_gtk_trees ();
+	create_groups_lists (ud->node, &user_settings_all_list, &user_settings_members_list);
+	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_all), user_settings_all_list);
+	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_members), user_settings_members_list);
+	
+	/* Attach the GLists to the GtkTreeViews */
+	g_object_set_data (G_OBJECT (user_settings_all), "list", user_settings_all_list);
+	g_object_set_data (G_OBJECT (user_settings_members), "list", user_settings_members_list);
 	
 	/* Set password */
 	user_settings_dialog_prepare_password ();
@@ -818,7 +777,7 @@ user_settings_dialog_prepare (ug_data *ud)
 	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	gtk_window_set_title (GTK_WINDOW (w0), g_strdup_printf (_("Settings for user %s"), name));
 	g_free (name);
-
+	
 	gtk_widget_show (w0);
 }
 
